@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 #ifndef GNUMERIC_TOOLS_H
 #define GNUMERIC_TOOLS_H
@@ -30,7 +29,10 @@ typedef enum {
 	TOOL_ENGINE_CLEAN_UP
 } analysis_tool_engine_t;
 
-typedef gboolean (* analysis_tool_engine) (data_analysis_output_t *dao, gpointer specs,
+/* Note: when the engine is called with TOOL_ENGINE_CLEAN_UP, the GOCmdContext *gcc will be NULL. */
+
+typedef gboolean (* analysis_tool_engine) (GOCmdContext *gcc,
+					   data_analysis_output_t *dao, gpointer specs,
 					   analysis_tool_engine_t selector, gpointer result);
 
 
